Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/mono.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSebastien Pouliot <sebastien@ximian.com>2004-07-07 23:42:02 +0400
committerSebastien Pouliot <sebastien@ximian.com>2004-07-07 23:42:02 +0400
commit4474c0890f20e62df4242c3b9e9be951dcef1ef6 (patch)
tree545c4d62d72ac2f871d12dc5383d4e16bd7b3249 /mcs/class/System.Security/Assembly
parent4c2bbc43a0c2cdd065387416dd06ac2192c0b958 (diff)
2004-07-07 Sebastien Pouliot <sebastien@ximian.com>
* AssemblyInfo.cs: Added new attributes present in Fx 2.0. svn path=/trunk/mcs/; revision=30856
Diffstat (limited to 'mcs/class/System.Security/Assembly')
-rwxr-xr-xmcs/class/System.Security/Assembly/AssemblyInfo.cs29
-rwxr-xr-xmcs/class/System.Security/Assembly/ChangeLog4
2 files changed, 23 insertions, 10 deletions
diff --git a/mcs/class/System.Security/Assembly/ChangeLog b/mcs/class/System.Security/Assembly/ChangeLog
index 1aa92ab7564..8e0b1b34287 100755
--- a/mcs/class/System.Security/Assembly/ChangeLog
+++ b/mcs/class/System.Security/Assembly/ChangeLog
@@ -1,3 +1,7 @@
+2004-07-07 Sebastien Pouliot <sebastien@ximian.com>
+
+ * AssemblyInfo.cs: Added new attributes present in Fx 2.0.
+
2004-05-12 Sebastien Pouliot <sebastien@ximian.com>
* AssemblyInfo.cs: Reduce extra/missing in corcompare (again).
diff --git a/mcs/class/System.Security/Assembly/AssemblyInfo.cs b/mcs/class/System.Security/Assembly/AssemblyInfo.cs
index 5e3942c557c..0f99b152199 100755
--- a/mcs/class/System.Security/Assembly/AssemblyInfo.cs
+++ b/mcs/class/System.Security/Assembly/AssemblyInfo.cs
@@ -1,12 +1,12 @@
//
// AssemblyInfo.cs
//
// Author:
// Andreas Nahr (ClassDevelopment@A-SoftTech.com)
//
// (C) 2003 Ximian, Inc. http://www.ximian.com
-//
-
+// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
@@ -33,6 +33,7 @@ using System.Reflection;
using System.Resources;
using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
+using System.Security;
// General Information about the system assembly
@@ -47,15 +48,23 @@ using System.Runtime.InteropServices;
[assembly: SatelliteContractVersion ("1.0.5000.0")]
#endif
-//[assembly: AssemblyCompany ("MONO development team")]
-//[assembly: AssemblyCopyright ("(c) 2003-2004 Various Authors")]
-//[assembly: AssemblyDescription ("System.Security.dll")]
-//[assembly: AssemblyProduct ("MONO CLI")]
-//[assembly: AssemblyTitle ("System.Security.dll")]
-
[assembly: CLSCompliant (true)]
[assembly: ComVisible (false)]
[assembly: NeutralResourcesLanguage ("en-US")]
[assembly: AssemblyDelaySign (true)]
[assembly: AssemblyKeyFile ("../msfinal.pub")]
+
+#if NET_2_0
+[assembly: AssemblyCompany ("MONO development team")]
+[assembly: AssemblyCopyright ("Copyright (C) 2002-2004 Various Authors")]
+[assembly: AssemblyDefaultAlias ("")]
+[assembly: AssemblyDescription ("System.Security.dll")]
+[assembly: AssemblyFileVersion ("")]
+[assembly: AssemblyInformationalVersion ("")]
+[assembly: AssemblyProduct ("MONO CLI")]
+[assembly: AssemblyTitle ("System.Security.dll")]
+[assembly: AllowPartiallyTrustedCallers ()]
+
+[module: CompilationRelaxations (0)]
+#endif
@@ -1,12 +1,12 @@
// AssemblyInfo.cs
//
-// Author:
-// Andreas Nahr (ClassDevelopment@A-SoftTech.com)
+// Authors:
+// Andreas Nahr (ClassDevelopment@A-SoftTech.com)
+// Sebastien Pouliot <sebastien@ximian.com>
//
// (C) 2003 Ximian, Inc. http://www.ximian.com